==> dhall-yaml-1.2.12-100-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-yaml
version:              1.2.12
visibility:           public
id:                   dhall-yaml-1.2.12-DQmTeYgS6dK7Zrou3aziyk
key:                  dhall-yaml-1.2.12-DQmTeYgS6dK7Zrou3aziyk
license:              GPL-3.0-only
copyright:            2019 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and YAML
description:
    Use this package if you want to convert between Dhall expressions and YAML.
    You can use this package as a library or an executable:

    * See the "Dhall.Yaml" module if you want to use this package as a library

    * Use the @dhall-to-yaml-ng@ program from this package if you want an executable

category:             Compiler
abi:                  9697393b333f96ce93518e83f4e9b0d9
exposed:              True
exposed-modules:      Dhall.Yaml Dhall.YamlToDhall
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-yaml
hs-libraries:         HSdhall-yaml-1.2.12-DQmTeYgS6dK7Zrou3aziyk
depends:
    HsYAML-0.2.1.4-EUqzCNLmaR7tUuVDhygt3
    HsYAML-aeson-0.2.0.2-8mktUlNjaUR39Wz38DWrEn
    aeson-2.1.2.1-4XssoWP8s0tKPHSv4bO4jS base-4.17.2.1
    bytestring-0.11.5.3 dhall-1.42.2-7oHFJKW8lQF2laMHKoZtZu
    dhall-json-1.7.12-1IgvDUtIcd4LcXD9KwDqro
    optparse-applicative-0.18.1.0-1qQAtHv6qKDHnowaperQhI text-2.0.2
    vector-0.13.2.0-EWs7nDhBFQF5RfgCWU6KmC

haddock-interfaces:   /usr/share/doc/dhall-yaml/html/dhall-yaml.haddock
haddock-html:         /usr/share/doc/dhall-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-yaml-1.2.12-101-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall-yaml
version:              1.2.12
visibility:           public
id:                   dhall-yaml-1.2.12-EFUTYXBHBhZCL35sIRwysg
key:                  dhall-yaml-1.2.12-EFUTYXBHBhZCL35sIRwysg
license:              GPL-3.0-only
copyright:            2019 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Convert between Dhall and YAML
description:
    Use this package if you want to convert between Dhall expressions and YAML.
    You can use this package as a library or an executable:

    * See the "Dhall.Yaml" module if you want to use this package as a library

    * Use the @dhall-to-yaml-ng@ program from this package if you want an executable

category:             Compiler
abi:                  f951c3428b76630c3236101f6cae07e0
exposed:              True
exposed-modules:      Dhall.Yaml Dhall.YamlToDhall
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dhall-yaml-1.2.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-yaml
hs-libraries:         HSdhall-yaml-1.2.12-EFUTYXBHBhZCL35sIRwysg
depends:
    HsYAML-0.2.1.4-g3FVSb5my7FTpAHFHcUvM
    HsYAML-aeson-0.2.0.2-3MKq9JzABdW5Ohpkg3lWzI
    aeson-2.1.2.1-6q2KNYwRaL29rPm6MMaiUC base-4.17.2.1
    bytestring-0.11.5.3 dhall-1.42.2-Ine8xSr0hS16Y6kg7msV5w
    dhall-json-1.7.12-JLTjLxXeyrWCGZMbmFvUCP
    optparse-applicative-0.18.1.0-B5S7p3yvcpkHKfw0kuCuBU text-2.0.2
    vector-0.13.2.0-CQ8QMV1t4PN5YFZtNXivGS

haddock-interfaces:   /usr/share/doc/dhall-yaml/html/dhall-yaml.haddock
haddock-html:         /usr/share/doc/dhall-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
